Changelog
=========

.. You should *NOT* be adding new change log entries to this file.
   You should create a file in the news directory instead.
   For helpful instructions, please see:
   https://github.com/plone/plone.releaser/blob/master/ADD-A-NEWS-ITEM.rst

.. towncrier release notes start

1.0.4 (2020-04-22)
------------------

New features:


- Drop Python 2.6 support.
  Support 2.7, 3.5-3.8, PyPy2/3.
  Added tox for local testing.
  [maurits] (#2)


1.0.3 (2018-03-10)
------------------

Bug fixes:

- Release it as a wheel as well as an egg.
  [gforcada]

1.0.2 (2016-11-01)
------------------

New features:

- Test Python 3 compatibility.
  [datakurre]


1.0.1 - 2011-05-20
------------------

* Add license metadata.
  [davisagli]

1.0 - 2011-04-30
----------------

* No changes

1.0b1 - 2009-03-30
------------------

* Initial release
